@@ -284,10 +284,11 @@ def DXHTTPRequest(resource, data, method='POST', headers=None, auth=True, timeou
         if os.environ['DX_CA_CERT'] == 'NOVERIFY':
             kwargs['verify'] = False
 
-    response, last_error = None, None
+    last_error = None
     for retry in range(max_retries + 1):
         streaming_response_truncated = False
         try:
+            response = None
             response = session_handler.request(method, url, data=data, headers=headers, timeout=timeout, auth=auth,
                                                **kwargs)
 
