@@ -30,7 +30,7 @@ import os, sys, json, re
 import dxpy
 from .describe import get_ls_l_desc
 from ..exceptions import DXError
-from ..compat import str, input
+from ..compat import str, input, get_env_var
 
 def pick(choices, default=None, str_choices=None, prompt=None, allow_mult=False, more_choices=False):
     '''
@@ -464,12 +464,12 @@ def resolve_path(path, expected=None, expected_classes=None, multi_projects=Fals
         project = dxpy.WORKSPACE_ID
         if expected == 'folder' and project is None:
             raise ResolutionError('a project context was expected for a path, but a current project is not set, nor was one provided in the path (preceding a colon) in "' + path + '"')
-        wd = os.environ.get('DX_CLI_WD', '/')
+        wd = get_env_var('DX_CLI_WD', u'/')
 
     # Determine folderpath and entity_name if necessary
     if folderpath is None:
         folderpath = substrings[-1]
-        folderpath, entity_name = clean_folder_path(('' if len(folderpath) > 0 and folderpath[0] == '/' else wd + '/') + folderpath, expected)
+        folderpath, entity_name = clean_folder_path(('' if folderpath.startswith('/') else wd + '/') + folderpath, expected)
 
     if multi_projects:
         return (project_ids if project == 0 else [project]), folderpath, entity_name
